# Introduction 
common library to define pipeline interfaces

# Getting Started

## installation
you can install the package from [pypi](https://pypi.org/project/tgedr-pipeline-common/):

`pip install tgedr-pipeline-common`

## usage

TODO

## rationale

TODO


# Build
- check the `helper.sh` script

# Test
- check the `helper.sh` script

# Contribute
- just submit a PR to our [repository](https://github.com/tgedr/pipeline-common) when you want, we'll look at it
